<?php
/**
 * Plugin Name: Beget-Call
 * Description: Install beget call widget to site.
 * Author: Eugene Osipov
 * Version: 1.0.7
 * License: GPLv2
 * Text Domain: begetcall
 * Domain Path: /languages
 */



class beget_call_Plugin {
	function __construct() {
		add_action( 'init', array( $this, 'init' ) );
		add_action( 'admin_menu', array( $this, 'admin_menu' ) );
		add_action( 'admin_init', array( $this, 'admin_init' ) );
		add_action( 'wp_head', array( $this, 'wp_head' ) );

	}

	function init() {
		$this->options = array_merge( array(
			'beget-call-code' => '',
			'beget-call-code-button' => '<div data-beget-call data-beget-call-style></div>',
		), (array) get_option( 'beget-call', array() ) );

//		Только на русском пока :)
		load_plugin_textdomain( 'beget-call', false, basename( dirname( __FILE__ ) ) . '/languages' );

		if ( empty( $this->options['beget-call-code'] ) ){
			function no_code_notice() {
				echo _e( '<div id="message" class="error highlight"><b>Warning</b> head code isnt added for <a href="/wp-admin/options-general.php?page=beget-call">Beget-Call</a>!</div>', 'beget-call' );
			}

			add_action( 'admin_notices', 'no_code_notice' );
		}
	}

	function admin_init() {
		register_setting( 'beget-call', 'beget-call', array( $this, 'sanitize' ) );
		add_settings_section( 'general', '', '', 'beget-call' );
		add_settings_field( 'beget-call-code', __( 'Widget code', 'beget-call' ), array( $this, 'field_counter_code' ), 'beget-call', 'general' );
		add_settings_field( 'beget-call-code-button', __( 'Callback button code', 'beget-call' ), array( $this, 'field_button_code' ), 'beget-call', 'general' );
	}

	function sanitize( $input ) {
		$output = array();

		if ( isset( $input['beget-call-code'] ) )
			$output['beget-call-code'] = ( current_user_can( 'unfiltered_html' ) ) ? $input['beget-call-code'] : wp_kses_post( $input['beget-call-code'] );

		if ( isset( $input['beget-call-code'] ) )
			$output['beget-call-code-button'] = ( current_user_can( 'unfiltered_html' ) ) ? $input['beget-call-code-button'] : wp_kses_post( $input['beget-call-code-button'] );

		return $output;
	}

	function field_counter_code() {
		?>
		<textarea name="beget-call[beget-call-code]" class="code large-text" rows="10"><?php echo esc_textarea( $this->options['beget-call-code'] ); ?></textarea>
		<p class="description"><?php _e( 'If you do not have a Beget.Call code, you can <a href="https://cp.beget.ru/cloudservices">request one</a>.', 'beget-call' ); ?>
		<?php
	}

	function field_button_code() {
		?>

		<textarea name="beget-call[beget-call-code-button]" class="code large-text" rows="2"><?php echo esc_textarea( $this->options['beget-call-code-button'] ); ?></textarea>
		<?php
	}

	function admin_menu() {
		add_options_page( __( 'Beget Call', 'beget-call' ), __( 'Beget Call', 'beget-call' ), 'manage_options', 'beget-call', array( $this, 'render_options' ) );
	}

	function render_options() {
		?>
		<div class="wrap">
	        <h2><?php _e( 'Beget Call', 'beget-call' ); ?></h2>
	        <p><?php _e( 'Please enter your Beget Call code in the field below and click Save Changes.', 'beget-call' ); ?>
	        <p><?php _e( 'If you use button style of your widget, please, place the widget into your <a href="/wp-admin/widgets.php">template</a>.', 'beget-call' ); ?>
	        <form action="options.php" method="POST">
	            <?php settings_fields( 'beget-call' ); ?>
	            <?php do_settings_sections( 'beget-call' ); ?>
	            <?php submit_button(); ?>
	        </form>
	    </div>
		<?php
	}

	function wp_head() {
		if ( ! empty( $this->options['beget-call-code'] ) )
			echo $this->options['beget-call-code'];
	}



}


class beget_call_button extends WP_Widget {

    //process the new widget
    public function __construct() {
        $option = array(
            'classname' => 'beget_call_button',
            'description' => __( 'This is Beget call button', 'beget-call' )
        );
        $this->WP_Widget('beget_call_button', __( 'Beget Call button', 'beget-call' ), $option);
		$this->options = array_merge( array(
			'beget-call-code' => '',
		), (array) get_option( 'beget-call', array() ) );
    }


//build the widget settings form
    function form($instance) {
        echo _e( 'Beget Call button', 'beget-call' );
    }

//save the widget settings
    function update($new_instance, $old_instance) {

        return $old_instance;
    }

//display the widget
    function widget($args, $instance) {


		if ( ! empty( $this->options['beget-call-code'] ) ){
        	echo $before_widget;
        	echo $this->options['beget-call-code-button'];
        	echo $after_widget;
		}
    }

}



add_action('widgets_init', 'beget_call_button_register');

/**
 * Register the widget
 *
 * @since 1.0
 */
function beget_call_button_register() {
    register_widget('beget_call_button');
}

$GLOBALS['beget_call_plugin'] = new beget_call_Plugin;
